@@ -495,27 +495,6 @@ link_connection_from_fd (LinkConnection         *cnx,
 	CNX_UNLOCK (cnx);
 }
 
-static unsigned long
-get_inet_addr (const char *str)
-{
-        struct hostent *hp;
-        struct in_addr *addr_ptr;
-        unsigned long addr;
-
-        if (isdigit (*str)) {
-                        addr = inet_addr (str);
-                } else {
-                        if ((hp = gethostbyname (str)) != NULL) {
-
-                                addr_ptr = (struct in_addr *) hp->h_addr;
-
-                                addr = inet_addr (inet_ntoa (*addr_ptr));
-                        }
-                }
-
-        return addr;
-}
-
 static gboolean
 link_connection_do_initiate (LinkConnection        *cnx,
 			     const char            *proto_name,
@@ -535,21 +514,6 @@ link_connection_do_initiate (LinkConnection        *cnx,
 	if (!proto)
 		return FALSE;
 
-	if (host && (strcmp (proto_name, "IPv4") == 0)) {
-		
-		const char *local_host;
-		local_host = link_get_local_hostname ();
-
-		if (strcmp (host, local_host)) {
-			unsigned long inet_addr_host, inet_addr_local_host;
-			inet_addr_host = get_inet_addr (host);
-			inet_addr_local_host = get_inet_addr (local_host);
-
-			if (inet_addr_host != inet_addr_local_host)
-				return FALSE;
-		}
-	}
-
 	saddr = link_protocol_get_sockaddr (
 		proto, host, service, &saddr_len);
 
@@ -671,8 +635,10 @@ link_connection_do_initiate (LinkConnection        *cnx,
 static LinkConnectionStatus
 link_connection_wait_connected_T (LinkConnection *cnx)
 {
-	while (cnx && cnx->status == LINK_CONNECTING)
-		link_wait ();
+	while (cnx && cnx->status == LINK_CONNECTING) {
+		if (!link_wait ())
+			link_connection_disconnect (cnx);
+	}
 
 	return cnx ? cnx->status : LINK_DISCONNECTED;
 }
@@ -695,8 +661,12 @@ link_connection_try_reconnect (LinkConnection *cnx)
 			cnx->inhibit_reconnect = FALSE;
 			dispatch_callbacks_drop_lock (cnx);
 			g_main_context_release (NULL);
-		} else 
-			link_wait ();
+		} else {
+			if (!link_wait ()) {
+				link_connection_disconnect (cnx);
+				break;
+			}
+		}
 	}
 
 	if (cnx->status != LINK_DISCONNECTED)
